@@ -1,5 +1,6 @@
 import hashlib
 import os
+import random
 import shlex
 import socket
 import subprocess
@@ -21,13 +22,27 @@ def humanize(n: int) -> str:
     return '%.1f MB' % (float(n) / MB)
 
 
+def is_port_in_use(port: int) -> bool:
+    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
+        return s.connect_ex(('127.0.0.1', port)) == 0
+
+
 def get_free_port():
-    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-    s.bind(('127.0.0.1', 0))
     try:
-        return s.getsockname()[1]
-    finally:
-        s.close()
+        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        s.bind(('127.0.0.1', 0))
+        try:
+            return s.getsockname()[1]
+        finally:
+            s.close()
+    except OSError:
+        # bind 0 will fail on Manjaro, fallback to random port
+        # https://github.com/openatx/adbutils/issues/85
+        for _ in range(20):
+            port = random.randint(10000, 20000)
+            if not is_port_in_use(port):
+                return port
+        raise RuntimeError("No free port found")
 
 
 def list2cmdline(args: typing.Union[list, tuple]):
@@ -186,24 +201,32 @@ class StopEvent:
     def __init__(self):
         self.__stop = threading.Event()
         self.__done = threading.Event()
-
-    def stop(self):
-        """ send stop signal """
-        self.__stop.set()
     
-    def stop_wait(self, timeout=None):
-        """ send stop signal and wait signal accepted """
+    def stop(self, timeout=None):
+        """ send stop signal and wait signal accepted 
+        
+        Raises:
+            TimeoutError
+        """
         self.__stop.set()
         if not self.__done.wait(timeout):
             raise TimeoutError("wait for stopped timeout", timeout)
 
+    def stop_nowait(self):
+        """ send stop signal """
+        self.__stop.set()
+
     def is_stopped(self) -> bool:
-        return self.__done.is_set()
+        return self.__stop.is_set()
 
     def done(self):
         """ for worker thread to notify stop signal accepted """
         self.__done.set()
     
+    def is_done(self) -> bool:
+        """ check if background worker has stopped """
+        return self.__done.is_set()
+    
     def reset(self):
         self.__stop.clear()
         self.__done.clear()
\ No newline at end of file
